<?php

/***************************************************************
 * Extension Manager/Repository config file for ext "patch10011".
 *
 * Auto generated 02-05-2022 12:30
 *
 * Manual updates:
 * Only the data in the array - everything else is removed by next
 * writing. "version" and "dependencies" must not be touched!
 ***************************************************************/

$EM_CONF[$_EXTKEY] = array (
  'title' => 'Startsite bp15 + bootstrap 5 + typo3 13',
  'description' => 'bootstrap 5 per bootstrap package 15, finisher per Powemail',
  'category' => 'misc',
  'version' => '8.2.4',
  'state' => 'dev',
  'uploadfolder' => false,
  'clearcacheonload' => true,
  'author' => 'Alex Tuveri',
  'author_email' => 'at@specialistaweb.it',
  'author_company' => 'specialistaweb.it',
  'constraints' => 
  array (
    'depends' => 
    array (
      'typo3' => '12.0.0-13.4.99',
      'bootstrap_package' => '14.0.0-15.99.99',
    ),
    'conflicts' => 
    array (
    ),
    'suggests' => 
    array (
      'bootstrap_package' => '14.0.0-15.99.99',
    ),
  ),
);

